@@ -1,4 +1,4 @@
-#    $Id: Nominet.pm,v 1.8 2014/10/31 17:24:06 pete Exp $
+#    $Id: Nominet.pm,v 1.11 2015/08/21 16:07:26 pete Exp $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.02_01';
+	our $VERSION = '0.02_02';
 }
 
 # file-scoped lexicals
@@ -791,8 +791,6 @@ changes like this:
 		'add'          => { ns => ['ns1.newhost.com', 'ns2.newhost.com'] },
 		'rem'          => { ns => ['ns1.oldhost.net', 'ns2.oldhost.net'] },
 		'chg'          => {},
-		'first-bill'   => 'th',
-		'recur-bill'   => 'th',
 		'auto-bill'    => 21,
 		'auto-period'  => 5,
 		'next-bill'    => '',
@@ -821,11 +819,10 @@ eg:
 		'rem'          => {}
 	};
 
-The extension fields can only be set outside of the add, rem and chg
-fields. The supported extensions in this module are:
-first-bill, recur-bill, auto-bill, auto-period, next-bill, next-period
-and notes. All of these are scalars aside from notes which is an array
-ref.
+The extension fields can only be set outside of the add, rem and
+chg fields. The supported extensions in this module are: auto-bill,
+auto-period, next-bill, next-period, renew-not-required and notes. All
+of these are scalars aside from notes which is an array ref.
 
 C<update_domain()> returns undef on failure, 1 on success.
 
@@ -873,8 +870,8 @@ sub modify_domain {
 	# Extensions
 	@spec = $self->spec ('domain-nom-ext');
 	$obj  = $frame->addObject (@spec);
-	for my $field (qw/ first-bill recur-bill auto-bill auto-period
-			next-bill next-period reseller /) {
+	for my $field (qw/ auto-bill auto-period
+			next-bill next-period renew-not-required reseller /) {
 		next unless ($data->{$field});
 		my $name = $frame->createElement("domain-nom-ext:$field");
 		$name->appendText ($data->{$field});
@@ -1160,13 +1157,8 @@ sub _info {
 		my $extra2 = $response->getNode('secDNS:infData');
 		return $self->_domain_infData_to_hash($infData, $extra);
 	} elsif ($type eq 'contact') {
+		$self->_clean_addr($infData);
 		my $this = $self->_contact_infData_to_hash($infData);
-		# Strip out the strange empty addr entries created by
-		# Net::EPP::Simple
-		for my $subtype ('int', 'loc') {
-			delete $this->{postalInfo}->{$subtype}->{addr}->{''} if
-				$this->{postalInfo}->{$subtype};
-		}
 		# Add in the Nominet extras (reg, rather than contact)
 		my $extra = $response->getNode('contact-nom-ext:infData');
 		return $self->_merge_contact_infData ($this, $extra);
@@ -1181,9 +1173,9 @@ sub _domain_infData_to_hash {
 	my $hash = $self->_node_to_hash ($infData, ['registrant',
 		'clID', 'crID', 'crDate', 'exDate', 'name', 'roid']);
 
-	my $extrahash = $self->_node_to_hash ($extra, ['first-bill',
-	'recur-bill', 'auto-bill', 'next-bill', 'auto-period',
-	'next-period', 'reg-status', 'notes', 'reseller']);
+	my $extrahash = $self->_node_to_hash ($extra, [
+	'auto-bill', 'next-bill', 'auto-period',
+	'next-period', 'reg-status', 'renew-not-required', 'notes', 'reseller']);
 
 	for (keys %$extrahash) {
 		$hash->{$_} = $extrahash->{$_};
@@ -1197,6 +1189,18 @@ sub _domain_infData_to_hash {
 	return $hash;
 }
 
+sub _clean_addr {
+	my ($self, $infData) = @_;
+	# Remove the whitespace text nodes from the addresses as
+	# Net::EPP::Simple does not handle them nicely
+	for my $addr ($infData->getElementsByTagName('contact:addr')) {
+		for my $child ($addr->childNodes) {
+			$addr->removeChild ($child)
+				unless $child->nodeType == XML::LibXML::XML_ELEMENT_NODE;
+		}
+	}
+}
+
 sub _merge_contact_infData {
 	my ($self, $old, $extra) = @_;
 
@@ -1521,7 +1525,7 @@ sub _send_frame {
 =over
 
 =item * The poll, fork, handshake, lock, tag list and reseller operations
-are not yet supported. Nor is there any DNSSEC facility yet.
+are not yet supported.
 
 =item * Retrieving contact info can generate warnings from the
 superclass. Ideally this processing should be done locally (within this
@@ -1553,7 +1557,7 @@ Pete Houston <cpan@openstrike.co.uk>
 
 =head1 Licence
 
-This software is copyright (c) 2013 by Pete Houston. It is released
+This software is copyright (c) 2013-2015 by Pete Houston. It is released
 under the Artistic Licence (version 2) and the
 GNU General Public Licence (version 2).
 
